Hypex.Register.Bitstring (Hypex v2.1.0)
View SourceA Hypex.Register implementation using a bitstring.
This register is useful for keeping memory usage down, while still offering good performance. You should consider this register when memory constraints are an important factor.
Recommended for larger widths, or when memory efficiency is a major concern.
Summary
Functions
Retrieve a specific bit from a register.
Initialize an empty array register of a given width.
Merge together two registers of the same width and type.
Set a specific bit in a register.
Run a reduction over the inner bits of a register.
Types
@type t() :: bitstring()
Functions
Retrieve a specific bit from a register.
Initialize an empty array register of a given width.
Merge together two registers of the same width and type.
Set a specific bit in a register.
@spec reduce(t(), width :: number(), accumulator :: any(), (number(), any() -> any())) :: accumulator :: any()
Run a reduction over the inner bits of a register.