Hypex.Register.List (Hypex v2.1.0)
View SourceA Hypex.Register implementation using a List.
Lists offer efficient storage for small widths, for both reading and writing. They do not scale well (at all) to larger widths, and should be avoided in these cases.
Recommended for smaller widths up to 10, or in testing and debugging.
Summary
Functions
Retrieve a specific bit from a register.
Initialize an empty array register of a given width.
Merge together two registers of the same width and type.
Set a specific bit in a register.
Run a reduction over the inner bits of a register.
Types
@type t() :: list()
Functions
Retrieve a specific bit from a register.
Initialize an empty array register of a given width.
Merge together two registers of the same width and type.
Set a specific bit in a register.
@spec reduce(t(), width :: number(), accumulator :: any(), (number(), any() -> any())) :: accumulator :: any()
Run a reduction over the inner bits of a register.