Hypex.Register.Tuple (Hypex v2.1.0)
View SourceA Hypex.Register implementation using a Tuple.
Tuples offer quick access and are useful for read-heavy use cases. Due to creation of a new tuple on write, not recommended for frequent writes due to memory churn.
Recommended for read-heavy use cases with widths generally up to 12.
Summary
Functions
Retrieve a specific bit from a register.
Initialize an empty array register of a given width.
Merge together two registers of the same width and type.
Set a specific bit in a register.
Run a reduction over the inner bits of a register.
Types
@type t() :: map()
Functions
Retrieve a specific bit from a register.
Initialize an empty array register of a given width.
Merge together two registers of the same width and type.
Set a specific bit in a register.
@spec reduce(t(), width :: number(), accumulator :: any(), (number(), any() -> any())) :: accumulator :: any()
Run a reduction over the inner bits of a register.